@@ -78,7 +78,7 @@ function task_service {
     elif [ "$OSFAMILY" = "Debian" ]; then
         unitdir=${unitdir_debian}
         defaultsdir=${defaultsdir_debian}
-        sysv_codenames=("squeeze" "wheezy" "lucid" "precise" "trusty" "jessie")
+        sysv_codenames=("squeeze" "wheezy" "lucid" "precise" "trusty")
         if $(echo ${sysv_codenames[@]} | grep -q $CODENAME) ; then
             task install_source_deb_sysv
         else
@@ -110,7 +110,7 @@ function task_install_source_rpm_systemd {
     task postinst_permissions
 }
 
-# Source based install for Debian based setups
+# Source based install for Debian based + sysv setups
 function task_install_source_deb_sysv {
     task preinst_deb
     task install_deb
@@ -143,14 +143,14 @@ function task_install {
 
         install -m 0644 ext/system-config/services.d/bootstrap.cfg "${DESTDIR}${system_config_dir}/services.d/bootstrap.cfg"
     
-    install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
     install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
+    install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
-    install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
     install -m 0644 ext/config/conf.d/global.conf "${DESTDIR}${projconfdir}/conf.d/global.conf"
     install -m 0644 ext/config/conf.d/web-routes.conf "${DESTDIR}${projconfdir}/conf.d/web-routes.conf"
     install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
     install -m 0644 ext/config/conf.d/webserver.conf "${DESTDIR}${projconfdir}/conf.d/webserver.conf"
+    install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
 
     install -d -m 0755 "${DESTDIR}${app_prefix}/scripts"
     install -m 0755 install.sh "${DESTDIR}${app_prefix}/scripts"
@@ -163,13 +163,13 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
-    install -m 0755 ext/cli/stop "${DESTDIR}${app_prefix}/cli/apps/stop"
-    install -m 0755 ext/cli/irb "${DESTDIR}${app_prefix}/cli/apps/irb"
-    install -m 0755 ext/cli/ruby "${DESTDIR}${app_prefix}/cli/apps/ruby"
-    install -m 0755 ext/cli/start "${DESTDIR}${app_prefix}/cli/apps/start"
     install -m 0755 ext/cli/foreground "${DESTDIR}${app_prefix}/cli/apps/foreground"
     install -m 0755 ext/cli/reload "${DESTDIR}${app_prefix}/cli/apps/reload"
+    install -m 0755 ext/cli/stop "${DESTDIR}${app_prefix}/cli/apps/stop"
+    install -m 0755 ext/cli/start "${DESTDIR}${app_prefix}/cli/apps/start"
     install -m 0755 ext/cli/gem "${DESTDIR}${app_prefix}/cli/apps/gem"
+    install -m 0755 ext/cli/irb "${DESTDIR}${app_prefix}/cli/apps/irb"
+    install -m 0755 ext/cli/ruby "${DESTDIR}${app_prefix}/cli/apps/ruby"
     install -d -m 0755 "${DESTDIR}${rundir}"
     install -d -m 700 "${DESTDIR}${app_logdir}"
 }
@@ -226,9 +226,9 @@ function task_sysv_init_deb {
     install -d -m 0755 "${DESTDIR}${rundir}"
 }
 
-# Install the systemd and defaults configuration for Debian.
+# Install the systemd/sysv and defaults configuration for Debian.
 function task_systemd_deb {
-    task defaults_deb
+    task sysv_init_deb
     install -d -m 0755 "${DESTDIR}${unitdir_debian}"
     install -m 0644 ext/debian/puppetserver.service_file "${DESTDIR}${unitdir_debian}/puppetserver.service"
     install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
