@@ -3,7 +3,8 @@
            [java.util Date]
            [java.io InputStream ByteArrayOutputStream ByteArrayInputStream File]
            [java.nio.file Files Paths LinkOption]
-           [java.nio.file.attribute FileAttribute PosixFilePermissions])
+           [java.nio.file.attribute FileAttribute PosixFilePermissions]
+           (java.security KeyPair))
   (:require [me.raynes.fs :as fs]
             [schema.core :as schema]
             [clojure.string :as str]
@@ -18,7 +19,7 @@
             [puppetlabs.ssl-utils.core :as utils]
             [clj-yaml.core :as yaml]
             [puppetlabs.puppetserver.shell-utils :as shell-utils]
-            [puppetlabs.i18n.core :as i18n :refer [trs tru]]))
+            [puppetlabs.i18n.core :as i18n]))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Schemas
@@ -158,6 +159,14 @@
    :pp_department       "1.3.6.1.4.1.34380.1.1.15"
    :pp_cluster          "1.3.6.1.4.1.34380.1.1.16"
    :pp_provisioner      "1.3.6.1.4.1.34380.1.1.17"
+   :pp_region           "1.3.6.1.4.1.34380.1.1.18"
+   :pp_datacenter       "1.3.6.1.4.1.34380.1.1.19"
+   :pp_zone             "1.3.6.1.4.1.34380.1.1.20"
+   :pp_network          "1.3.6.1.4.1.34380.1.1.21"
+   :pp_securitypolicy   "1.3.6.1.4.1.34380.1.1.22"
+   :pp_cloudplatform    "1.3.6.1.4.1.34380.1.1.23"
+   :pp_apptier          "1.3.6.1.4.1.34380.1.1.24"
+   :pp_hostname         "1.3.6.1.4.1.34380.1.1.25"
    :pp_authorization    "1.3.6.1.4.1.34380.1.3.1"
    :pp_auth_role        "1.3.6.1.4.1.34380.1.3.13"})
 
@@ -165,10 +174,6 @@
   "Standard value applied to the Netscape Comment extension for certificates"
   "Puppet Server Internal Certificate")
 
-(def required-master-files
-  "The set of SSL files that are required on the master."
-  #{:hostprivkey :hostcert})
-
 (def required-ca-files
   "The set of SSL related files that are required on the CA."
   #{:cacert :cacrl :cakey :cert-inventory :serial})
@@ -294,19 +299,13 @@
    missing-files :- [schema/Str]]
   (IllegalStateException.
    (format "%s\n%s\n%s\n%s\n%s\n"
-           (trs "Cannot initialize {0} with partial state; need all files or none." master-or-ca)
-           (trs "Found:")
+           (i18n/trs "Cannot initialize {0} with partial state; need all files or none." master-or-ca)
+           (i18n/trs "Found:")
            (str/join "\n" found-files)
-           (trs "Missing:")
+           (i18n/trs "Missing:")
            (str/join "\n" missing-files))))
 
-; TODO - PE-5529 - these should be moved to jvm-c-a.
-(schema/defn get-subject :- schema/Str
-  [cert :- Certificate]
-  (-> cert
-      (.getSubjectX500Principal)
-      (.getName)))
-
+; TODO - PE-5529 - this should be moved to jvm-c-a.
 (schema/defn get-csr-subject :- schema/Str
   [csr :- CertificateRequest]
   (-> csr
@@ -408,7 +407,7 @@
         not-after     (-> cert
                           (.getNotAfter)
                           (format-date-time))
-        subject       (get-subject cert)
+        subject       (utils/get-subject-from-x509-certificate cert)
         entry (str serial-number " " not-before " " not-after " /" subject "\n")]
     (spit inventory-file entry :append true)))
 
@@ -426,18 +425,18 @@
                                        certificate-status-access-control)]
     (when (> ca-ttl max-ca-ttl)
       (throw (IllegalStateException.
-               (trs "Config setting ca_ttl must have a value below {0}" max-ca-ttl))))
+               (i18n/trs "Config setting ca_ttl must have a value below {0}" max-ca-ttl))))
     (cond
       (or (false? (:authorization-required certificate-status-access-control))
           (not-empty certificate-status-whitelist))
-      (log/warn (format "%s  %s"
-               (trs "The ''client-whitelist'' and ''authorization-required'' settings in the ''certificate-authority.certificate-status'' section are deprecated and will be removed in a future release.")
-               (trs "Remove these settings and create an appropriate authorization rule in the /etc/puppetlabs/puppetserver/conf.d/auth.conf file.")))
+      (log/warn (format "%s %s"
+               (i18n/trs "The ''client-whitelist'' and ''authorization-required'' settings in the ''certificate-authority.certificate-status'' section are deprecated and will be removed in a future release.")
+               (i18n/trs "Remove these settings and create an appropriate authorization rule in the /etc/puppetlabs/puppetserver/conf.d/auth.conf file.")))
       (not (nil? certificate-status-whitelist))
-      (log/warn (format "%s  %s  %s"
-                        (trs "The ''client-whitelist'' and ''authorization-required'' settings in the ''certificate-authority.certificate-status'' section are deprecated and will be removed in a future release.")
-                        (trs "Because the ''client-whitelist'' is empty and ''authorization-required'' is set to ''false'', the ''certificate-authority.certificate-status'' settings will be ignored and authorization for the ''certificate_status'' endpoints will be done per the authorization rules in the /etc/puppetlabs/puppetserver/conf.d/auth.conf file.")
-                        (trs "To suppress this warning, remove the ''certificate-authority'' configuration settings."))))))
+      (log/warn (format "%s %s %s"
+                        (i18n/trs "The ''client-whitelist'' and ''authorization-required'' settings in the ''certificate-authority.certificate-status'' section are deprecated and will be removed in a future release.")
+                        (i18n/trs "Because the ''client-whitelist'' is empty and ''authorization-required'' is set to ''false'', the ''certificate-authority.certificate-status'' settings will be ignored and authorization for the ''certificate_status'' endpoints will be done per the authorization rules in the /etc/puppetlabs/puppetserver/conf.d/auth.conf file.")
+                        (i18n/trs "To suppress this warning, remove the ''certificate-authority'' configuration settings."))))))
 
 (schema/defn create-ca-extensions :- (schema/pred utils/extension-list?)
   "Create a list of extensions to be added to the CA certificate."
@@ -459,7 +458,7 @@
   "Given the CA settings, generate and write to disk all of the necessary
   SSL files for the CA. Any existing files will be replaced."
   [ca-settings :- CaSettings]
-  (log/debug (str (trs "Initializing SSL for the CA; settings:")
+  (log/debug (str (i18n/trs "Initializing SSL for the CA; settings:")
                   "\n"
                   (ks/pprint-to-string ca-settings)))
   (create-parent-directories! (vals (settings->cadir-paths ca-settings)))
@@ -526,22 +525,22 @@
   (when-not (= hostname subject)
     (sling/throw+
       {:kind :hostname-mismatch
-       :msg (tru "Instance name \"{0}\" does not match requested key \"{1}\"" subject hostname)}))
+       :msg (i18n/tru "Instance name \"{0}\" does not match requested key \"{1}\"" subject hostname)}))
 
   (when (contains-uppercase? hostname)
     (sling/throw+
       {:kind :invalid-subject-name
-       :msg (tru "Certificate names must be lower case.")}))
+       :msg (i18n/tru "Certificate names must be lower case.")}))
 
   (when-not (re-matches #"\A[ -.0-~]+\Z" subject)
     (sling/throw+
       {:kind :invalid-subject-name
-       :msg (tru "Subject contains unprintable or non-ASCII characters")}))
+       :msg (i18n/tru "Subject contains unprintable or non-ASCII characters")}))
 
   (when (.contains subject "*")
     (sling/throw+
       {:kind :invalid-subject-name
-       :msg (tru "Subject contains a wildcard, which is not allowed: {0}" subject)})))
+       :msg (i18n/tru "Subject contains a wildcard, which is not allowed: {0}" subject)})))
 
 (schema/defn allowed-extension?
   "A predicate that answers if an extension is allowed or not.
@@ -560,7 +559,7 @@
     (when-not (empty? bad-extensions)
       (let [bad-extension-oids (map :oid bad-extensions)]
         (sling/throw+ {:kind :disallowed-extension
-                       :msg (tru "Found extensions that are not permitted: {0}"
+                       :msg (i18n/tru "Found extensions that are not permitted: {0}"
                                  (str/join ", " bad-extension-oids))})))))
 
 (schema/defn validate-dns-alt-names!
@@ -575,13 +574,13 @@
                    (= (first name-types) :dns-name))
       (sling/throw+
         {:kind :invalid-alt-name
-         :msg (tru "Only DNS names are allowed in the Subject Alternative Names extension")}))
+         :msg (i18n/tru "Only DNS names are allowed in the Subject Alternative Names extension")}))
 
     (doseq [name names]
       (when (.contains name "*")
         (sling/throw+
           {:kind :invalid-alt-name
-           :msg (tru "Cert subjectAltName contains a wildcard, which is not allowed: {0}"
+           :msg (i18n/tru "Cert subjectAltName contains a wildcard, which is not allowed: {0}"
                  name)})))))
 
 (schema/defn create-csr-attrs-exts :- (schema/maybe (schema/pred utils/extension-list?))
@@ -597,7 +596,7 @@
               :critical false
               :value (str value)})
            ext-req))
-    (log/debug (trs "No CSR Attributes configuration file found at {0}, CSR Attributes will not be loaded"
+    (log/debug (i18n/trs "No CSR Attributes configuration file found at {0}, CSR Attributes will not be loaded"
                 csr-attributes-file))))
 
 (schema/defn create-master-extensions :- (schema/pred utils/extension-list?)
@@ -625,6 +624,48 @@
       (validate-extensions! csr-attr-exts))
     (remove nil? (concat base-ext-list [alt-names-ext] csr-attr-exts))))
 
+(schema/defn generate-master-ssl-keys!* :- (schema/pred utils/public-key?)
+  "Generate and store ssl public and private keys for the master to disk.
+  Returns the public key."
+  [{:keys [hostprivkey hostpubkey keylength]} :- MasterSettings]
+  (log/debug (i18n/trs "Generating public and private keys for master cert"))
+  (let [keypair (utils/generate-key-pair keylength)
+        public-key (utils/get-public-key keypair)
+        private-key (utils/get-private-key keypair)]
+    (utils/key->pem! public-key hostpubkey)
+    (utils/key->pem! private-key
+                     (create-file-with-perms hostprivkey
+                                             private-key-perms))
+    public-key))
+
+(schema/defn generate-master-ssl-keys! :- (schema/pred utils/public-key?)
+  "Generate and store ssl public and private keys for the master to disk.  If
+  the files are both already present, new ones will not be generated to replace
+  them.  Returns the public key."
+  [{:keys [hostprivkey hostpubkey] :as settings} :- MasterSettings]
+  (cond
+    (and (fs/exists? hostprivkey) (fs/exists? hostpubkey))
+    (do
+      (log/debug (i18n/trs "Using keys found on disk to generate master cert"))
+      (utils/pem->public-key hostpubkey))
+
+    (and (not (fs/exists? hostprivkey)) (not (fs/exists? hostpubkey)))
+    (generate-master-ssl-keys!* settings)
+
+    (fs/exists? hostpubkey)
+    (throw
+     (IllegalStateException.
+      (i18n/trs "Found master public key ''{0}'' but master private key ''{1}'' is missing"
+                hostpubkey
+                hostprivkey)))
+
+    :else
+    (throw
+     (IllegalStateException.
+      (i18n/trs "Found master private key ''{0}'' but master public key ''{1}'' is missing"
+                hostprivkey
+                hostpubkey)))))
+
 (schema/defn generate-master-ssl-files!
   "Given master configuration settings, certname, and CA settings,
    generate and write to disk all of the necessary SSL files for
@@ -633,7 +674,7 @@
    certname :- schema/Str
    ca-settings :- CaSettings]
   (log/debug (format "%s\n%s"
-                     (trs "Initializing SSL for the Master; settings:")
+                     (i18n/trs "Initializing SSL for the Master; settings:")
                      (ks/pprint-to-string settings)))
   (create-parent-directories! (vals (settings->ssldir-paths settings)))
   (set-file-perms (:privatekeydir settings) private-key-dir-perms)
@@ -643,16 +684,15 @@
         ca-public-key  (.getPublicKey ca-cert)
         ca-private-key (utils/pem->private-key (:cakey ca-settings))
         next-serial    (next-serial-number! (:serial ca-settings))
-        keypair        (utils/generate-key-pair (:keylength settings))
-        public-key     (utils/get-public-key keypair)
+        public-key     (generate-master-ssl-keys! settings)
         extensions     (create-master-extensions certname
                                                  public-key
                                                  ca-public-key
                                                  settings)
-        private-key    (utils/get-private-key keypair)
         x500-name      (utils/cn certname)
         validity       (cert-validity-dates (:ca-ttl ca-settings))
-        hostcert       (utils/sign-certificate (get-subject ca-cert)
+        hostcert       (utils/sign-certificate (utils/get-subject-from-x509-certificate
+                                                ca-cert)
                                                ca-private-key
                                                next-serial
                                                (:not-before validity)
@@ -661,9 +701,6 @@
                                                public-key
                                                extensions)]
     (write-cert-to-inventory! hostcert (:cert-inventory ca-settings))
-    (utils/key->pem! public-key (:hostpubkey settings))
-    (utils/key->pem! private-key
-     (create-file-with-perms (:hostprivkey settings) private-key-perms))
     (utils/cert->pem! hostcert (:hostcert settings))
     (utils/cert->pem! hostcert
                       (path-to-cert (:signeddir ca-settings) certname))))
@@ -672,19 +709,22 @@
   "Given configuration settings, certname, and CA settings, ensure all
    necessary SSL files exist on disk by regenerating all of them if any
    are found to be missing."
-  [settings :- MasterSettings
-    certname :- schema/Str
-    ca-settings :- CaSettings]
-     (let [required-files (-> (settings->ssldir-paths settings)
-                              (select-keys required-master-files)
-                              (vals))]
-       (if (every? fs/exists? required-files)
-         (log/info (trs "Master already initialized for SSL"))
-         (let [{found   true
-                missing false} (group-by fs/exists? required-files)]
-           (if (= required-files missing)
-             (generate-master-ssl-files! settings certname ca-settings)
-             (throw (partial-state-error "master" found missing)))))))
+  [{:keys [hostprivkey hostcert] :as settings} :- MasterSettings
+   certname :- schema/Str
+   ca-settings :- CaSettings]
+  (cond
+    (and (fs/exists? hostcert) (fs/exists? hostprivkey))
+    (log/info (i18n/trs "Master already initialized for SSL"))
+
+    (fs/exists? hostcert)
+    (throw
+     (IllegalStateException.
+      (i18n/trs "Found master cert ''{0}'' but master private key ''{1}'' is missing"
+           hostcert
+           hostprivkey)))
+
+    :else
+    (generate-master-ssl-files! settings certname ca-settings)))
 
 (schema/defn ^:always-validate retrieve-ca-cert!
   "Ensure a local copy of the CA cert is available on disk.  cacert is the base
@@ -698,7 +738,7 @@
        (fs/copy cacert localcacert))
      (if-not (fs/exists? localcacert)
        (throw (IllegalStateException.
-               (trs ":localcacert ({0}) could not be found and no file at :cacert ({1}) to copy it from"
+               (i18n/trs ":localcacert ({0}) could not be found and no file at :cacert ({1}) to copy it from"
                     localcacert cacert)))))))
 
 (schema/defn ^:always-validate retrieve-ca-crl!
@@ -745,7 +785,7 @@
    subject :- schema/Str
    line :- schema/Str]
   (if (or (.contains line "#") (.contains line " "))
-    (do (log/error (trs "Invalid pattern ''{0}'' found in {1}" line whitelist))
+    (do (log/error (i18n/trs "Invalid pattern ''{0}'' found in {1}" line whitelist))
         false)
     (if (= line "*")
       true
@@ -781,7 +821,7 @@
    subject :- schema/Str
    csr-stream :- InputStream
    ruby-load-path :- [schema/Str]]
-  (log/debug (trs "Executing ''{0} {1}''" executable subject))
+  (log/debug (i18n/trs "Executing ''{0} {1}''" executable subject))
   (let [env     (into {} (System/getenv))
         rubylib (->> (if-let [lib (get env "RUBYLIB")]
                        (cons lib ruby-load-path)
@@ -793,15 +833,15 @@
                  {:args [subject]
                   :in csr-stream
                   :env (merge env {"RUBYLIB" rubylib})})]
-    (log/debug (trs "Autosign command ''{0} {1}'' exit status: {2}"
+    (log/debug (i18n/trs "Autosign command ''{0} {1}'' exit status: {2}"
                 executable subject (:exit-code results)))
-    (log/debug (trs "Autosign command ''{0} {1}'' output on stdout: {2}"
+    (log/debug (i18n/trs "Autosign command ''{0} {1}'' output on stdout: {2}"
                 executable subject (:stdout results)))
     (when-not (empty? (:stderr results))
-      (log/warn (trs "Autosign command ''{0} {1}'' generated output to stderr: {2}"
+      (log/warn (i18n/trs "Autosign command ''{0} {1}'' generated output to stderr: {2}"
                  executable subject (:stderr results))))
     (when-not (zero? (:exit-code results))
-      (log/warn (trs "Autosign command ''{0}'' rejected certificate ''{1}'' because the exit code was {2}, not zero"
+      (log/warn (i18n/trs "Autosign command ''{0}'' rejected certificate ''{1}'' because the exit code was {2}, not zero"
                  executable subject (:exit-code results))))
     results))
 
@@ -899,7 +939,8 @@
    {:keys [cacert cakey signeddir ca-ttl serial cert-inventory]} :- CaSettings]
   (let [validity    (cert-validity-dates ca-ttl)
         cacert      (utils/pem->cert cacert)
-        signed-cert (utils/sign-certificate (get-subject cacert)
+        signed-cert (utils/sign-certificate (utils/get-subject-from-x509-certificate
+                                             cacert)
                                             (utils/pem->private-key cakey)
                                             (next-serial-number! serial)
                                             (:not-before validity)
@@ -909,7 +950,7 @@
                                             (create-agent-extensions
                                              csr
                                              (.getPublicKey cacert)))]
-    (log/info (trs "Signed certificate request for {0}" subject))
+    (log/info (i18n/trs "Signed certificate request for {0}" subject))
     (write-cert-to-inventory! signed-cert cert-inventory)
     (utils/cert->pem! signed-cert (path-to-cert signeddir subject))))
 
@@ -920,7 +961,7 @@
    csr :- CertificateRequest
    csrdir :- schema/Str]
   (let [csr-path (path-to-cert-request csrdir subject)]
-    (log/debug (trs "Saving CSR to ''{0}''" csr-path))
+    (log/debug (i18n/trs "Saving CSR to ''{0}''" csr-path))
     (utils/obj->pem! csr csr-path)))
 
 (schema/defn validate-duplicate-cert-policy!
@@ -943,10 +984,10 @@
                        "signed")
                      "requested")]
         (if allow-duplicate-certs
-          (log/info (trs "{0} already has a {1} certificate; new certificate will overwrite it" subject status))
+          (log/info (i18n/trs "{0} already has a {1} certificate; new certificate will overwrite it" subject status))
           (sling/throw+
             {:kind :duplicate-cert
-             :msg (tru "{0} already has a {1} certificate; ignoring certificate request" subject status)}))))))
+             :msg (i18n/tru "{0} already has a {1} certificate; ignoring certificate request" subject status)}))))))
 
 (schema/defn validate-csr-signature!
   "Throws an exception when the CSR's signature is invalid.
@@ -955,7 +996,7 @@
   (when-not (utils/signature-valid? certificate-request)
     (sling/throw+
       {:kind :invalid-signature
-       :msg (tru "CSR contains a public key that does not correspond to the signing key")})))
+       :msg (i18n/tru "CSR contains a public key that does not correspond to the signing key")})))
 
 (schema/defn ensure-no-authorization-extensions!
   "Throws an exception if the CSR contains authorization exceptions. These
@@ -969,8 +1010,8 @@
         (sling/throw+
          {:kind :disallowed-extension
           :msg (format "%s %s"
-                (trs "CSR ''{0}'' contains an authorization extension, which is disallowed." csr)
-                (trs "Use {0} to sign this request."
+                (i18n/trs "CSR ''{0}'' contains an authorization extension, which is disallowed." csr)
+                (i18n/trs "Use {0} to sign this request."
                      (format "`puppet cert --allow-authorization-extensions sign %s`"
                              (get-csr-subject csr))))})))))
 
@@ -982,8 +1023,8 @@
       (sling/throw+
        {:kind :disallowed-extension
         :msg (format "%s %s"
-                     (tru "CSR ''{0}'' contains subject alternative names ({1}), which are disallowed." subject (str/join ", " dns-alt-names))
-                     (tru "Use `puppet cert --allow-dns-alt-names sign {0}` to sign this request." subject))}))))
+                     (i18n/tru "CSR ''{0}'' contains subject alternative names ({1}), which are disallowed." subject (str/join ", " dns-alt-names))
+                     (i18n/tru "Use `puppet cert --allow-dns-alt-names sign {0}` to sign this request." subject))}))))
 
 
 (schema/defn ^:always-validate process-csr-submission!
@@ -1016,15 +1057,15 @@
   (let [csr-path (path-to-cert-request csrdir subject)]
     (if (fs/exists? csr-path)
       (if (fs/delete csr-path)
-        (let [msg (trs "Deleted certificate request for {0}" subject)]
+        (let [msg (i18n/trs "Deleted certificate request for {0}" subject)]
           (log/debug msg)
           {:outcome :success
            :message msg})
-        (let [msg (trs "Path {0} exists but could not be deleted" csr-path)]
+        (let [msg (i18n/trs "Path {0} exists but could not be deleted" csr-path)]
           (log/error msg)
           {:outcome :error
            :message msg}))
-      (let [msg (trs "No certificate request for {0} at expected path {1}"
+      (let [msg (i18n/trs "No certificate request for {0} at expected path {1}"
                   subject csr-path)]
         (log/warn msg)
         {:outcome :not-found
@@ -1054,9 +1095,9 @@
     (when-not (= private-key-perms cur-perms)
       (set-file-perms ca-p-key private-key-perms)
       (log/warn (format "%s %s"
-                        (trs "The private CA key at ''{0}'' was found to have the wrong permissions set as ''{1}''."
+                        (i18n/trs "The private CA key at ''{0}'' was found to have the wrong permissions set as ''{1}''."
                              ca-p-key cur-perms)
-                        (trs "This has been corrected to ''{0}''."
+                        (i18n/trs "This has been corrected to ''{0}''."
                              private-key-perms))))))
 
 (schema/defn ^:always-validate
@@ -1072,7 +1113,7 @@
                             (vals))]
      (if (every? fs/exists? required-files)
        (do
-         (log/info (trs "CA already initialized for SSL"))
+         (log/info (i18n/trs "CA already initialized for SSL"))
          (when (:manage-internal-file-permissions settings)
            (ensure-ca-file-perms! settings)))
        (let [{found   true
@@ -1149,7 +1190,7 @@
   (let [csr-path (path-to-cert-request csrdir subject)]
     (autosign-certificate-request! subject (utils/pem->csr csr-path) settings)
     (fs/delete csr-path)
-    (log/debug (trs "Removed certificate request for {0} at ''{1}''" subject csr-path))))
+    (log/debug (i18n/trs "Removed certificate request for {0} at ''{1}''" subject csr-path))))
 
 (schema/defn revoke-existing-cert!
   "Revoke the subject's certificate. Note this does not destroy the certificate.
@@ -1164,7 +1205,7 @@
                               (.getPublicKey (utils/pem->cert cacert))
                               serial)]
     (utils/crl->pem! new-crl cacrl)
-    (log/debug (trs "Revoked {0} certificate with serial {1}" subject serial))))
+    (log/debug (i18n/trs "Revoked {0} certificate with serial {1}" subject serial))))
 
 (schema/defn ^:always-validate set-certificate-status!
   "Sign or revoke the certificate for the given subject."
@@ -1231,7 +1272,7 @@
   (let [cert (path-to-cert signeddir subject)]
     (when (fs/exists? cert)
       (fs/delete cert)
-      (log/debug (trs "Deleted certificate for {0}" subject)))))
+      (log/debug (i18n/trs "Deleted certificate for {0}" subject)))))
 
 (schema/defn ^:always-validate get-custom-oid-mappings :- (schema/maybe OIDMappings)
   "Given a path to a custom OID mappings file, return a map of all oids to
@@ -1240,7 +1281,7 @@
   (if (fs/file? custom-oid-mapping-file)
     (let [oid-mappings (:oid_mapping (yaml/parse-string (slurp custom-oid-mapping-file)))]
       (into {} (for [[oid names] oid-mappings] [(name oid) (keyword (:shortname names))])))
-    (log/debug (trs "No custom OID mapping configuration file found at {0}, custom OID mappings will not be loaded"
+    (log/debug (i18n/trs "No custom OID mapping configuration file found at {0}, custom OID mappings will not be loaded"
                 custom-oid-mapping-file))))
 
 (schema/defn ^:always-validate get-oid-mappings :- OIDMappings
