@@ -7,7 +7,7 @@
             [puppetlabs.puppetserver.certificate-authority :as ca]
             [puppetlabs.services.master.master-core :as master-core]
             [puppetlabs.trapperkeeper.services :as tk-services]
-            [puppetlabs.i18n.core :as i18n :refer [trs]]))
+            [puppetlabs.i18n.core :as i18n]))
 
 (tk/defservice legacy-routes-service
   [[:WebroutingService add-ring-handler get-route]
@@ -74,5 +74,5 @@
     context)
   (start
     [this context]
-    (log/info (trs "The legacy routing service has successfully started and is now ready to handle requests"))
+    (log/info (i18n/trs "The legacy routing service has successfully started and is now ready to handle requests"))
     context))
