@@ -17,15 +17,23 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Schemas
 
+(def WholeSeconds schema/Int)
+(def WholeMilliseconds schema/Int)
+
 (def ServiceStatusDetailLevel
   (schema/enum :critical :info :debug))
 
 (def State
   (schema/enum :running :error :starting :stopping :unknown))
 
+(def Alert
+  {:severity (schema/enum :error :warning :info)
+   :message schema/Str})
+
 (def StatusCallbackResponse
   {:state State
-   :status schema/Any})
+   :status schema/Any
+   (schema/optional-key :alerts) [Alert]})
 
 (def StatusFn (schema/make-fn-schema StatusCallbackResponse ServiceStatusDetailLevel))
 
@@ -41,14 +49,13 @@
 
 ;; this is what gets returned in the HTTP response as json, and thus uses
 ;; underscores rather than hyphens
-;; TODO: merge StatusCallbackResponse with this, rather than duplicating its
-;; two keys, and remove underscores from this schema.
 (def ServiceStatus
   {:service_version schema/Str
    :service_status_version schema/Int
    :state State
    :detail_level ServiceStatusDetailLevel
-   :status schema/Any})
+   :status schema/Any
+   :active_alerts [Alert]})
 
 (def ServicesStatus
   {schema/Str ServiceStatus})
@@ -70,8 +77,8 @@
 (def JvmMetricsV1
   {:heap-memory MemoryUsageV1
    :non-heap-memory MemoryUsageV1
-   :up-time-ms schema/Int
-   :start-time-ms schema/Int})
+   :up-time-ms WholeMilliseconds
+   :start-time-ms WholeMilliseconds})
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Private
@@ -96,12 +103,12 @@
     (validation-error-explain schema-failure)
     schema-failure))
 
-(schema/defn check-timeout :- schema/Int
-  "Given a status level keyword, returns a number of seconds to use as a timeout
-  when calling a status function."
+(schema/defn check-timeout :- WholeSeconds
+  "Given a status level keyword, returns an integral number of seconds to use as
+  a timeout when calling a status function."
   [level :- ServiceStatusDetailLevel]
   (case level
-    :critical 5
+    :critical 30
     :info 60
     :debug 60))
 
@@ -216,8 +223,8 @@
 
 (schema/defn ^:always-validate guarded-status-fn-call :- StatusCallbackResponse
   "Given a status check function, a status detail level, and a timeout in
-  seconds, this function calls the status function and handles three types of
-  errors:
+  (integral) seconds, this function calls the status function and handles three
+  types of errors:
 
   * Status check timed out
   * Status check threw an Exception
@@ -227,7 +234,7 @@
   string describing the error."
   [status-fn :- StatusFn
    level :- ServiceStatusDetailLevel
-   timeout :- schema/Int]
+   timeout :- WholeSeconds]
    (let [unknown-response (fn [status] {:state :unknown
                                         :status status})
          timeout-response (unknown-response (format "Status check timed out after %s seconds" timeout))]
@@ -287,32 +294,36 @@
   :unknown for :state."
   ([service-name :- schema/Str
     service :- [ServiceInfo]
-    level :- ServiceStatusDetailLevel]
-    (call-status-fn-for-service service-name service level nil))
+    level :- ServiceStatusDetailLevel
+    timeout :- WholeSeconds]
+    (call-status-fn-for-service service-name service level timeout nil))
   ([service-name :- schema/Str
     service :- [ServiceInfo]
     level :- ServiceStatusDetailLevel
+    timeout :- WholeSeconds
     service-status-version :- (schema/maybe schema/Int)]
    (let [status (matching-service-info service-name service service-status-version)
-         timeout (check-timeout level)
          callback-resp (guarded-status-fn-call (:status-fn status) level timeout)
          data (:status callback-resp)
          state (if-not (schema/check State (:state callback-resp))
                  (:state callback-resp)
-                 :unknown)]
+                 :unknown)
+         alerts (get callback-resp :alerts [])]
        {:service_version (:service-version status)
         :service_status_version (:service-status-version status)
         :detail_level level
         :state state
-        :status data})))
+        :status data
+        :active_alerts alerts})))
 
 (schema/defn ^:always-validate call-status-fns :- ServicesStatus
   "Call the latest status function for each service in the service context,
   and return a map of service to service status."
   [status-fns :- ServicesInfo
-   level :- ServiceStatusDetailLevel]
+   level :- ServiceStatusDetailLevel
+   timeout :- WholeSeconds]
   (try
-    (into {} (pmap (fn [[k v]] {k (call-status-fn-for-service k v level)})
+    (into {} (pmap (fn [[k v]] {k (call-status-fn-for-service k v level timeout)})
                status-fns))
     ;; pmap returns all exceptions that occur while it is executing tasks in a
     ;; java.util.concurrent.ExecutionException. This unwraps and rethrows
@@ -336,12 +347,30 @@
   "Given a params map from a request, get out the service status version and
    check whether it is valid. If not, throw an error."
   [params]
-  (when-let [level (params :service_status_version)]
-    (if-let [parsed-level (ks/parse-int level)]
-      parsed-level
+  (when-let [version (params :service_status_version)]
+    (if-let [numeric-version (ks/parse-int version)]
+      numeric-version
       (ringutils/throw-data-invalid!
        (str "Invalid service_status_version. Should be an integer but was "
-            level)))))
+            version)))))
+
+(defn get-timeout
+  "Given a params map from a request, attempt to find the timeout parameter and
+  parse it as an integer, returning the numeric value. If no timeout parameter
+  is found, return nil. If the parameter isn't parseable as an integer, throw an
+  exception."
+  [params]
+  (let [timeout-param (:timeout params)
+        numeric-timeout (and timeout-param (ks/parse-int timeout-param))]
+    (cond
+      (nil? timeout-param) nil
+      (nil? numeric-timeout) (ringutils/throw-data-invalid!
+                               (str "Invalid timeout. Should be an integer but was "
+                                    timeout-param))
+      (<= numeric-timeout 0) (ringutils/throw-data-invalid!
+                               (str "Invalid timeout. Timeout must be greater than zero but was"
+                                    numeric-timeout))
+      :else numeric-timeout)))
 
 (schema/defn ^:always-validate summarize-states :- State
   "Given a map of service statuses, return the 'most severe' state present as
@@ -375,18 +404,21 @@
 (defn build-plaintext-routes
   [path status-fns]
   (comidi/context path
-     (comidi/GET "" _
-       (let [statuses (call-status-fns status-fns :critical)]
+     (comidi/GET "" [:as {params :params}]
+       (let [timeout (or (get-timeout params) (check-timeout :critical))
+             statuses (call-status-fns status-fns :critical timeout)]
          (ringutils/plain-response (statuses->code statuses)
            (-> statuses
                summarize-states
                name))))
 
-     (comidi/GET ["/" :service-name] [service-name]
+     (comidi/GET ["/" :service-name] [service-name :as {params :params}]
        (if-let [service-info (get status-fns service-name)]
-         (let [status (call-status-fn-for-service service-name
+         (let [timeout (or (get-timeout params) (check-timeout :critical))
+               status (call-status-fn-for-service service-name
                                                   service-info
-                                                  :critical)]
+                                                  :critical
+                                                  timeout)]
            (ringutils/plain-response (status->code status)
              (name (:state status))))
          (ringutils/plain-response 404
@@ -397,7 +429,8 @@
   (comidi/context path
       (comidi/GET "" [:as {params :params}]
         (let [level (get-status-detail-level params)
-              statuses (call-status-fns status-fns level)]
+              timeout (or (get-timeout params) (check-timeout level))
+              statuses (call-status-fns status-fns level timeout)]
           (ringutils/json-response (statuses->code statuses)
             statuses)))
 
@@ -405,9 +438,11 @@
         (if-let [service-info (get status-fns service-name)]
           (let [level (get-status-detail-level params)
                 service-status-version (get-service-status-version params)
-                status (call-status-fn-for-service service-name
+                status (call-status-fn-for-service
+                         service-name
                          service-info
                          level
+                         (or (get-timeout params) (check-timeout level))
                          service-status-version)]
             (ringutils/json-response (status->code status)
               (assoc status :service_name service-name)))
